
# Client

::: incydr.Client
    :docstring:
    :members: settings session request_history cases customer departments devices file_events directory_groups file_events users user_risk_profiles watchlists
